"""
Main interface for wellarchitected service client

Usage::

    ```python
    import boto3
    from mypy_boto3_wellarchitected import WellArchitectedClient

    client: WellArchitectedClient = boto3.client("wellarchitected")
    ```
"""
import sys
from typing import Any, Dict, List, Type

from botocore.client import ClientMeta

from mypy_boto3_wellarchitected.type_defs import (
    CreateMilestoneOutputTypeDef,
    CreateWorkloadOutputTypeDef,
    CreateWorkloadShareOutputTypeDef,
    GetAnswerOutputTypeDef,
    GetLensReviewOutputTypeDef,
    GetLensReviewReportOutputTypeDef,
    GetLensVersionDifferenceOutputTypeDef,
    GetMilestoneOutputTypeDef,
    GetWorkloadOutputTypeDef,
    ListAnswersOutputTypeDef,
    ListLensesOutputTypeDef,
    ListLensReviewImprovementsOutputTypeDef,
    ListLensReviewsOutputTypeDef,
    ListMilestonesOutputTypeDef,
    ListNotificationsOutputTypeDef,
    ListShareInvitationsOutputTypeDef,
    ListTagsForResourceOutputTypeDef,
    ListWorkloadSharesOutputTypeDef,
    ListWorkloadsOutputTypeDef,
    UpdateAnswerOutputTypeDef,
    UpdateLensReviewOutputTypeDef,
    UpdateShareInvitationOutputTypeDef,
    UpdateWorkloadOutputTypeDef,
    UpdateWorkloadShareOutputTypeDef,
)

if sys.version_info >= (3, 8):
    from typing import Literal
else:
    from typing_extensions import Literal


__all__ = ("WellArchitectedClient",)


class BotocoreClientError(BaseException):
    MSG_TEMPLATE: str

    def __init__(self, error_response: Dict[str, Any], operation_name: str) -> None:
        self.response: Dict[str, Any]
        self.operation_name: str


class Exceptions:
    AccessDeniedException: Type[BotocoreClientError]
    ClientError: Type[BotocoreClientError]
    ConflictException: Type[BotocoreClientError]
    InternalServerException: Type[BotocoreClientError]
    ResourceNotFoundException: Type[BotocoreClientError]
    ServiceQuotaExceededException: Type[BotocoreClientError]
    ThrottlingException: Type[BotocoreClientError]
    ValidationException: Type[BotocoreClientError]


class WellArchitectedClient:
    """
    [WellArchitected.Client documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.46/reference/services/wellarchitected.html#WellArchitected.Client)
    """

    meta: ClientMeta
    exceptions: Exceptions

    def associate_lenses(self, WorkloadId: str, LensAliases: List[str]) -> None:
        """
        [Client.associate_lenses documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.46/reference/services/wellarchitected.html#WellArchitected.Client.associate_lenses)
        """

    def can_paginate(self, operation_name: str) -> bool:
        """
        [Client.can_paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.46/reference/services/wellarchitected.html#WellArchitected.Client.can_paginate)
        """

    def create_milestone(
        self, WorkloadId: str, MilestoneName: str, ClientRequestToken: str
    ) -> CreateMilestoneOutputTypeDef:
        """
        [Client.create_milestone documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.46/reference/services/wellarchitected.html#WellArchitected.Client.create_milestone)
        """

    def create_workload(
        self,
        WorkloadName: str,
        Description: str,
        Environment: Literal["PRODUCTION", "PREPRODUCTION"],
        ReviewOwner: str,
        Lenses: List[str],
        ClientRequestToken: str,
        AccountIds: List[str] = None,
        AwsRegions: List[str] = None,
        NonAwsRegions: List[str] = None,
        PillarPriorities: List[str] = None,
        ArchitecturalDesign: str = None,
        IndustryType: str = None,
        Industry: str = None,
        Notes: str = None,
        Tags: Dict[str, str] = None,
    ) -> CreateWorkloadOutputTypeDef:
        """
        [Client.create_workload documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.46/reference/services/wellarchitected.html#WellArchitected.Client.create_workload)
        """

    def create_workload_share(
        self,
        WorkloadId: str,
        SharedWith: str,
        PermissionType: Literal["READONLY", "CONTRIBUTOR"],
        ClientRequestToken: str,
    ) -> CreateWorkloadShareOutputTypeDef:
        """
        [Client.create_workload_share documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.46/reference/services/wellarchitected.html#WellArchitected.Client.create_workload_share)
        """

    def delete_workload(self, WorkloadId: str, ClientRequestToken: str) -> None:
        """
        [Client.delete_workload documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.46/reference/services/wellarchitected.html#WellArchitected.Client.delete_workload)
        """

    def delete_workload_share(self, ShareId: str, WorkloadId: str, ClientRequestToken: str) -> None:
        """
        [Client.delete_workload_share documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.46/reference/services/wellarchitected.html#WellArchitected.Client.delete_workload_share)
        """

    def disassociate_lenses(self, WorkloadId: str, LensAliases: List[str]) -> None:
        """
        [Client.disassociate_lenses documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.46/reference/services/wellarchitected.html#WellArchitected.Client.disassociate_lenses)
        """

    def generate_presigned_url(
        self,
        ClientMethod: str,
        Params: Dict[str, Any] = None,
        ExpiresIn: int = 3600,
        HttpMethod: str = None,
    ) -> str:
        """
        [Client.generate_presigned_url documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.46/reference/services/wellarchitected.html#WellArchitected.Client.generate_presigned_url)
        """

    def get_answer(
        self, WorkloadId: str, LensAlias: str, QuestionId: str, MilestoneNumber: int = None
    ) -> GetAnswerOutputTypeDef:
        """
        [Client.get_answer documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.46/reference/services/wellarchitected.html#WellArchitected.Client.get_answer)
        """

    def get_lens_review(
        self, WorkloadId: str, LensAlias: str, MilestoneNumber: int = None
    ) -> GetLensReviewOutputTypeDef:
        """
        [Client.get_lens_review documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.46/reference/services/wellarchitected.html#WellArchitected.Client.get_lens_review)
        """

    def get_lens_review_report(
        self, WorkloadId: str, LensAlias: str, MilestoneNumber: int = None
    ) -> GetLensReviewReportOutputTypeDef:
        """
        [Client.get_lens_review_report documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.46/reference/services/wellarchitected.html#WellArchitected.Client.get_lens_review_report)
        """

    def get_lens_version_difference(
        self, LensAlias: str, BaseLensVersion: str
    ) -> GetLensVersionDifferenceOutputTypeDef:
        """
        [Client.get_lens_version_difference documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.46/reference/services/wellarchitected.html#WellArchitected.Client.get_lens_version_difference)
        """

    def get_milestone(self, WorkloadId: str, MilestoneNumber: int) -> GetMilestoneOutputTypeDef:
        """
        [Client.get_milestone documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.46/reference/services/wellarchitected.html#WellArchitected.Client.get_milestone)
        """

    def get_workload(self, WorkloadId: str) -> GetWorkloadOutputTypeDef:
        """
        [Client.get_workload documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.46/reference/services/wellarchitected.html#WellArchitected.Client.get_workload)
        """

    def list_answers(
        self,
        WorkloadId: str,
        LensAlias: str,
        PillarId: str = None,
        MilestoneNumber: int = None,
        NextToken: str = None,
        MaxResults: int = None,
    ) -> ListAnswersOutputTypeDef:
        """
        [Client.list_answers documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.46/reference/services/wellarchitected.html#WellArchitected.Client.list_answers)
        """

    def list_lens_review_improvements(
        self,
        WorkloadId: str,
        LensAlias: str,
        PillarId: str = None,
        MilestoneNumber: int = None,
        NextToken: str = None,
        MaxResults: int = None,
    ) -> ListLensReviewImprovementsOutputTypeDef:
        """
        [Client.list_lens_review_improvements documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.46/reference/services/wellarchitected.html#WellArchitected.Client.list_lens_review_improvements)
        """

    def list_lens_reviews(
        self,
        WorkloadId: str,
        MilestoneNumber: int = None,
        NextToken: str = None,
        MaxResults: int = None,
    ) -> ListLensReviewsOutputTypeDef:
        """
        [Client.list_lens_reviews documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.46/reference/services/wellarchitected.html#WellArchitected.Client.list_lens_reviews)
        """

    def list_lenses(self, NextToken: str = None, MaxResults: int = None) -> ListLensesOutputTypeDef:
        """
        [Client.list_lenses documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.46/reference/services/wellarchitected.html#WellArchitected.Client.list_lenses)
        """

    def list_milestones(
        self, WorkloadId: str, NextToken: str = None, MaxResults: int = None
    ) -> ListMilestonesOutputTypeDef:
        """
        [Client.list_milestones documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.46/reference/services/wellarchitected.html#WellArchitected.Client.list_milestones)
        """

    def list_notifications(
        self, WorkloadId: str = None, NextToken: str = None, MaxResults: int = None
    ) -> ListNotificationsOutputTypeDef:
        """
        [Client.list_notifications documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.46/reference/services/wellarchitected.html#WellArchitected.Client.list_notifications)
        """

    def list_share_invitations(
        self, WorkloadNamePrefix: str = None, NextToken: str = None, MaxResults: int = None
    ) -> ListShareInvitationsOutputTypeDef:
        """
        [Client.list_share_invitations documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.46/reference/services/wellarchitected.html#WellArchitected.Client.list_share_invitations)
        """

    def list_tags_for_resource(self, WorkloadArn: str) -> ListTagsForResourceOutputTypeDef:
        """
        [Client.list_tags_for_resource documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.46/reference/services/wellarchitected.html#WellArchitected.Client.list_tags_for_resource)
        """

    def list_workload_shares(
        self,
        WorkloadId: str,
        SharedWithPrefix: str = None,
        NextToken: str = None,
        MaxResults: int = None,
    ) -> ListWorkloadSharesOutputTypeDef:
        """
        [Client.list_workload_shares documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.46/reference/services/wellarchitected.html#WellArchitected.Client.list_workload_shares)
        """

    def list_workloads(
        self, WorkloadNamePrefix: str = None, NextToken: str = None, MaxResults: int = None
    ) -> ListWorkloadsOutputTypeDef:
        """
        [Client.list_workloads documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.46/reference/services/wellarchitected.html#WellArchitected.Client.list_workloads)
        """

    def tag_resource(self, WorkloadArn: str, Tags: Dict[str, str]) -> Dict[str, Any]:
        """
        [Client.tag_resource documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.46/reference/services/wellarchitected.html#WellArchitected.Client.tag_resource)
        """

    def untag_resource(self, WorkloadArn: str, TagKeys: List[str]) -> Dict[str, Any]:
        """
        [Client.untag_resource documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.46/reference/services/wellarchitected.html#WellArchitected.Client.untag_resource)
        """

    def update_answer(
        self,
        WorkloadId: str,
        LensAlias: str,
        QuestionId: str,
        SelectedChoices: List[str] = None,
        Notes: str = None,
        IsApplicable: bool = None,
    ) -> UpdateAnswerOutputTypeDef:
        """
        [Client.update_answer documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.46/reference/services/wellarchitected.html#WellArchitected.Client.update_answer)
        """

    def update_lens_review(
        self,
        WorkloadId: str,
        LensAlias: str,
        LensNotes: str = None,
        PillarNotes: Dict[str, str] = None,
    ) -> UpdateLensReviewOutputTypeDef:
        """
        [Client.update_lens_review documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.46/reference/services/wellarchitected.html#WellArchitected.Client.update_lens_review)
        """

    def update_share_invitation(
        self, ShareInvitationId: str, ShareInvitationAction: Literal["ACCEPT", "REJECT"]
    ) -> UpdateShareInvitationOutputTypeDef:
        """
        [Client.update_share_invitation documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.46/reference/services/wellarchitected.html#WellArchitected.Client.update_share_invitation)
        """

    def update_workload(
        self,
        WorkloadId: str,
        WorkloadName: str = None,
        Description: str = None,
        Environment: Literal["PRODUCTION", "PREPRODUCTION"] = None,
        AccountIds: List[str] = None,
        AwsRegions: List[str] = None,
        NonAwsRegions: List[str] = None,
        PillarPriorities: List[str] = None,
        ArchitecturalDesign: str = None,
        ReviewOwner: str = None,
        IsReviewOwnerUpdateAcknowledged: bool = None,
        IndustryType: str = None,
        Industry: str = None,
        Notes: str = None,
        ImprovementStatus: Literal[
            "NOT_APPLICABLE", "NOT_STARTED", "IN_PROGRESS", "COMPLETE", "RISK_ACKNOWLEDGED"
        ] = None,
    ) -> UpdateWorkloadOutputTypeDef:
        """
        [Client.update_workload documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.46/reference/services/wellarchitected.html#WellArchitected.Client.update_workload)
        """

    def update_workload_share(
        self, ShareId: str, WorkloadId: str, PermissionType: Literal["READONLY", "CONTRIBUTOR"]
    ) -> UpdateWorkloadShareOutputTypeDef:
        """
        [Client.update_workload_share documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.46/reference/services/wellarchitected.html#WellArchitected.Client.update_workload_share)
        """

    def upgrade_lens_review(
        self, WorkloadId: str, LensAlias: str, MilestoneName: str, ClientRequestToken: str = None
    ) -> None:
        """
        [Client.upgrade_lens_review documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.46/reference/services/wellarchitected.html#WellArchitected.Client.upgrade_lens_review)
        """



"""
Main interface for wellarchitected service type definitions.

Usage::

    ```python
    from mypy_boto3_wellarchitected.type_defs import AnswerSummaryTypeDef

    data: AnswerSummaryTypeDef = {...}
    ```
"""
import sys
from datetime import datetime
from typing import Any, Dict, List

if sys.version_info >= (3, 8):
    from typing import Literal
else:
    from typing_extensions import Literal
if sys.version_info >= (3, 8):
    from typing import TypedDict
else:
    from typing_extensions import TypedDict


__all__ = (
    "AnswerSummaryTypeDef",
    "AnswerTypeDef",
    "ChoiceTypeDef",
    "ImprovementSummaryTypeDef",
    "LensReviewReportTypeDef",
    "LensReviewSummaryTypeDef",
    "LensReviewTypeDef",
    "LensSummaryTypeDef",
    "LensUpgradeSummaryTypeDef",
    "MilestoneSummaryTypeDef",
    "MilestoneTypeDef",
    "NotificationSummaryTypeDef",
    "PillarDifferenceTypeDef",
    "PillarReviewSummaryTypeDef",
    "QuestionDifferenceTypeDef",
    "ResponseMetadata",
    "ShareInvitationSummaryTypeDef",
    "ShareInvitationTypeDef",
    "VersionDifferencesTypeDef",
    "WorkloadShareSummaryTypeDef",
    "WorkloadShareTypeDef",
    "WorkloadSummaryTypeDef",
    "WorkloadTypeDef",
    "CreateMilestoneOutputTypeDef",
    "CreateWorkloadOutputTypeDef",
    "CreateWorkloadShareOutputTypeDef",
    "GetAnswerOutputTypeDef",
    "GetLensReviewOutputTypeDef",
    "GetLensReviewReportOutputTypeDef",
    "GetLensVersionDifferenceOutputTypeDef",
    "GetMilestoneOutputTypeDef",
    "GetWorkloadOutputTypeDef",
    "ListAnswersOutputTypeDef",
    "ListLensReviewImprovementsOutputTypeDef",
    "ListLensReviewsOutputTypeDef",
    "ListLensesOutputTypeDef",
    "ListMilestonesOutputTypeDef",
    "ListNotificationsOutputTypeDef",
    "ListShareInvitationsOutputTypeDef",
    "ListTagsForResourceOutputTypeDef",
    "ListWorkloadSharesOutputTypeDef",
    "ListWorkloadsOutputTypeDef",
    "UpdateAnswerOutputTypeDef",
    "UpdateLensReviewOutputTypeDef",
    "UpdateShareInvitationOutputTypeDef",
    "UpdateWorkloadOutputTypeDef",
    "UpdateWorkloadShareOutputTypeDef",
)

AnswerSummaryTypeDef = TypedDict(
    "AnswerSummaryTypeDef",
    {
        "QuestionId": str,
        "PillarId": str,
        "QuestionTitle": str,
        "Choices": List["ChoiceTypeDef"],
        "SelectedChoices": List[str],
        "IsApplicable": bool,
        "Risk": Literal["UNANSWERED", "HIGH", "MEDIUM", "NONE", "NOT_APPLICABLE"],
    },
    total=False,
)

AnswerTypeDef = TypedDict(
    "AnswerTypeDef",
    {
        "QuestionId": str,
        "PillarId": str,
        "QuestionTitle": str,
        "QuestionDescription": str,
        "ImprovementPlanUrl": str,
        "HelpfulResourceUrl": str,
        "Choices": List["ChoiceTypeDef"],
        "SelectedChoices": List[str],
        "IsApplicable": bool,
        "Risk": Literal["UNANSWERED", "HIGH", "MEDIUM", "NONE", "NOT_APPLICABLE"],
        "Notes": str,
    },
    total=False,
)

ChoiceTypeDef = TypedDict(
    "ChoiceTypeDef", {"ChoiceId": str, "Title": str, "Description": str}, total=False
)

ImprovementSummaryTypeDef = TypedDict(
    "ImprovementSummaryTypeDef",
    {
        "QuestionId": str,
        "PillarId": str,
        "QuestionTitle": str,
        "Risk": Literal["UNANSWERED", "HIGH", "MEDIUM", "NONE", "NOT_APPLICABLE"],
        "ImprovementPlanUrl": str,
    },
    total=False,
)

LensReviewReportTypeDef = TypedDict(
    "LensReviewReportTypeDef", {"LensAlias": str, "Base64String": str}, total=False
)

LensReviewSummaryTypeDef = TypedDict(
    "LensReviewSummaryTypeDef",
    {
        "LensAlias": str,
        "LensVersion": str,
        "LensName": str,
        "LensStatus": Literal["CURRENT", "NOT_CURRENT", "DEPRECATED"],
        "UpdatedAt": datetime,
        "RiskCounts": Dict[Literal["UNANSWERED", "HIGH", "MEDIUM", "NONE", "NOT_APPLICABLE"], int],
    },
    total=False,
)

LensReviewTypeDef = TypedDict(
    "LensReviewTypeDef",
    {
        "LensAlias": str,
        "LensVersion": str,
        "LensName": str,
        "LensStatus": Literal["CURRENT", "NOT_CURRENT", "DEPRECATED"],
        "PillarReviewSummaries": List["PillarReviewSummaryTypeDef"],
        "UpdatedAt": datetime,
        "Notes": str,
        "RiskCounts": Dict[Literal["UNANSWERED", "HIGH", "MEDIUM", "NONE", "NOT_APPLICABLE"], int],
        "NextToken": str,
    },
    total=False,
)

LensSummaryTypeDef = TypedDict(
    "LensSummaryTypeDef",
    {"LensAlias": str, "LensVersion": str, "LensName": str, "Description": str},
    total=False,
)

LensUpgradeSummaryTypeDef = TypedDict(
    "LensUpgradeSummaryTypeDef",
    {
        "WorkloadId": str,
        "WorkloadName": str,
        "LensAlias": str,
        "CurrentLensVersion": str,
        "LatestLensVersion": str,
    },
    total=False,
)

MilestoneSummaryTypeDef = TypedDict(
    "MilestoneSummaryTypeDef",
    {
        "MilestoneNumber": int,
        "MilestoneName": str,
        "RecordedAt": datetime,
        "WorkloadSummary": "WorkloadSummaryTypeDef",
    },
    total=False,
)

MilestoneTypeDef = TypedDict(
    "MilestoneTypeDef",
    {
        "MilestoneNumber": int,
        "MilestoneName": str,
        "RecordedAt": datetime,
        "Workload": "WorkloadTypeDef",
    },
    total=False,
)

NotificationSummaryTypeDef = TypedDict(
    "NotificationSummaryTypeDef",
    {
        "Type": Literal["LENS_VERSION_UPGRADED", "LENS_VERSION_DEPRECATED"],
        "LensUpgradeSummary": "LensUpgradeSummaryTypeDef",
    },
    total=False,
)

PillarDifferenceTypeDef = TypedDict(
    "PillarDifferenceTypeDef",
    {
        "PillarId": str,
        "DifferenceStatus": Literal["UPDATED", "NEW", "DELETED"],
        "QuestionDifferences": List["QuestionDifferenceTypeDef"],
    },
    total=False,
)

PillarReviewSummaryTypeDef = TypedDict(
    "PillarReviewSummaryTypeDef",
    {
        "PillarId": str,
        "PillarName": str,
        "Notes": str,
        "RiskCounts": Dict[Literal["UNANSWERED", "HIGH", "MEDIUM", "NONE", "NOT_APPLICABLE"], int],
    },
    total=False,
)

QuestionDifferenceTypeDef = TypedDict(
    "QuestionDifferenceTypeDef",
    {
        "QuestionId": str,
        "QuestionTitle": str,
        "DifferenceStatus": Literal["UPDATED", "NEW", "DELETED"],
    },
    total=False,
)

ResponseMetadata = TypedDict(
    "ResponseMetadata",
    {
        "RequestId": str,
        "HostId": str,
        "HTTPStatusCode": int,
        "HTTPHeaders": Dict[str, Any],
        "RetryAttempts": int,
    },
)

ShareInvitationSummaryTypeDef = TypedDict(
    "ShareInvitationSummaryTypeDef",
    {
        "ShareInvitationId": str,
        "SharedBy": str,
        "SharedWith": str,
        "PermissionType": Literal["READONLY", "CONTRIBUTOR"],
        "WorkloadName": str,
        "WorkloadId": str,
    },
    total=False,
)

ShareInvitationTypeDef = TypedDict(
    "ShareInvitationTypeDef", {"ShareInvitationId": str, "WorkloadId": str}, total=False
)

VersionDifferencesTypeDef = TypedDict(
    "VersionDifferencesTypeDef", {"PillarDifferences": List["PillarDifferenceTypeDef"]}, total=False
)

WorkloadShareSummaryTypeDef = TypedDict(
    "WorkloadShareSummaryTypeDef",
    {
        "ShareId": str,
        "SharedWith": str,
        "PermissionType": Literal["READONLY", "CONTRIBUTOR"],
        "Status": Literal["ACCEPTED", "REJECTED", "PENDING", "REVOKED", "EXPIRED"],
    },
    total=False,
)

WorkloadShareTypeDef = TypedDict(
    "WorkloadShareTypeDef",
    {
        "ShareId": str,
        "SharedBy": str,
        "SharedWith": str,
        "PermissionType": Literal["READONLY", "CONTRIBUTOR"],
        "Status": Literal["ACCEPTED", "REJECTED", "PENDING", "REVOKED", "EXPIRED"],
        "WorkloadName": str,
        "WorkloadId": str,
    },
    total=False,
)

WorkloadSummaryTypeDef = TypedDict(
    "WorkloadSummaryTypeDef",
    {
        "WorkloadId": str,
        "WorkloadArn": str,
        "WorkloadName": str,
        "Owner": str,
        "UpdatedAt": datetime,
        "Lenses": List[str],
        "RiskCounts": Dict[Literal["UNANSWERED", "HIGH", "MEDIUM", "NONE", "NOT_APPLICABLE"], int],
        "ImprovementStatus": Literal[
            "NOT_APPLICABLE", "NOT_STARTED", "IN_PROGRESS", "COMPLETE", "RISK_ACKNOWLEDGED"
        ],
    },
    total=False,
)

WorkloadTypeDef = TypedDict(
    "WorkloadTypeDef",
    {
        "WorkloadId": str,
        "WorkloadArn": str,
        "WorkloadName": str,
        "Description": str,
        "Environment": Literal["PRODUCTION", "PREPRODUCTION"],
        "UpdatedAt": datetime,
        "AccountIds": List[str],
        "AwsRegions": List[str],
        "NonAwsRegions": List[str],
        "ArchitecturalDesign": str,
        "ReviewOwner": str,
        "ReviewRestrictionDate": datetime,
        "IsReviewOwnerUpdateAcknowledged": bool,
        "IndustryType": str,
        "Industry": str,
        "Notes": str,
        "ImprovementStatus": Literal[
            "NOT_APPLICABLE", "NOT_STARTED", "IN_PROGRESS", "COMPLETE", "RISK_ACKNOWLEDGED"
        ],
        "RiskCounts": Dict[Literal["UNANSWERED", "HIGH", "MEDIUM", "NONE", "NOT_APPLICABLE"], int],
        "PillarPriorities": List[str],
        "Lenses": List[str],
        "Owner": str,
        "ShareInvitationId": str,
        "Tags": Dict[str, str],
    },
    total=False,
)

CreateMilestoneOutputTypeDef = TypedDict(
    "CreateMilestoneOutputTypeDef",
    {"WorkloadId": str, "MilestoneNumber": int, "ResponseMetadata": "ResponseMetadata"},
    total=False,
)

CreateWorkloadOutputTypeDef = TypedDict(
    "CreateWorkloadOutputTypeDef",
    {"WorkloadId": str, "WorkloadArn": str, "ResponseMetadata": "ResponseMetadata"},
    total=False,
)

CreateWorkloadShareOutputTypeDef = TypedDict(
    "CreateWorkloadShareOutputTypeDef",
    {"WorkloadId": str, "ShareId": str, "ResponseMetadata": "ResponseMetadata"},
    total=False,
)

GetAnswerOutputTypeDef = TypedDict(
    "GetAnswerOutputTypeDef",
    {
        "WorkloadId": str,
        "MilestoneNumber": int,
        "LensAlias": str,
        "Answer": "AnswerTypeDef",
        "ResponseMetadata": "ResponseMetadata",
    },
    total=False,
)

GetLensReviewOutputTypeDef = TypedDict(
    "GetLensReviewOutputTypeDef",
    {
        "WorkloadId": str,
        "MilestoneNumber": int,
        "LensReview": "LensReviewTypeDef",
        "ResponseMetadata": "ResponseMetadata",
    },
    total=False,
)

GetLensReviewReportOutputTypeDef = TypedDict(
    "GetLensReviewReportOutputTypeDef",
    {
        "WorkloadId": str,
        "MilestoneNumber": int,
        "LensReviewReport": "LensReviewReportTypeDef",
        "ResponseMetadata": "ResponseMetadata",
    },
    total=False,
)

GetLensVersionDifferenceOutputTypeDef = TypedDict(
    "GetLensVersionDifferenceOutputTypeDef",
    {
        "LensAlias": str,
        "BaseLensVersion": str,
        "LatestLensVersion": str,
        "VersionDifferences": "VersionDifferencesTypeDef",
        "ResponseMetadata": "ResponseMetadata",
    },
    total=False,
)

GetMilestoneOutputTypeDef = TypedDict(
    "GetMilestoneOutputTypeDef",
    {"WorkloadId": str, "Milestone": "MilestoneTypeDef", "ResponseMetadata": "ResponseMetadata"},
    total=False,
)

GetWorkloadOutputTypeDef = TypedDict(
    "GetWorkloadOutputTypeDef",
    {"Workload": "WorkloadTypeDef", "ResponseMetadata": "ResponseMetadata"},
    total=False,
)

ListAnswersOutputTypeDef = TypedDict(
    "ListAnswersOutputTypeDef",
    {
        "WorkloadId": str,
        "MilestoneNumber": int,
        "LensAlias": str,
        "AnswerSummaries": List["AnswerSummaryTypeDef"],
        "NextToken": str,
        "ResponseMetadata": "ResponseMetadata",
    },
    total=False,
)

ListLensReviewImprovementsOutputTypeDef = TypedDict(
    "ListLensReviewImprovementsOutputTypeDef",
    {
        "WorkloadId": str,
        "MilestoneNumber": int,
        "LensAlias": str,
        "ImprovementSummaries": List["ImprovementSummaryTypeDef"],
        "NextToken": str,
        "ResponseMetadata": "ResponseMetadata",
    },
    total=False,
)

ListLensReviewsOutputTypeDef = TypedDict(
    "ListLensReviewsOutputTypeDef",
    {
        "WorkloadId": str,
        "MilestoneNumber": int,
        "LensReviewSummaries": List["LensReviewSummaryTypeDef"],
        "NextToken": str,
        "ResponseMetadata": "ResponseMetadata",
    },
    total=False,
)

ListLensesOutputTypeDef = TypedDict(
    "ListLensesOutputTypeDef",
    {
        "LensSummaries": List["LensSummaryTypeDef"],
        "NextToken": str,
        "ResponseMetadata": "ResponseMetadata",
    },
    total=False,
)

ListMilestonesOutputTypeDef = TypedDict(
    "ListMilestonesOutputTypeDef",
    {
        "WorkloadId": str,
        "MilestoneSummaries": List["MilestoneSummaryTypeDef"],
        "NextToken": str,
        "ResponseMetadata": "ResponseMetadata",
    },
    total=False,
)

ListNotificationsOutputTypeDef = TypedDict(
    "ListNotificationsOutputTypeDef",
    {
        "NotificationSummaries": List["NotificationSummaryTypeDef"],
        "NextToken": str,
        "ResponseMetadata": "ResponseMetadata",
    },
    total=False,
)

ListShareInvitationsOutputTypeDef = TypedDict(
    "ListShareInvitationsOutputTypeDef",
    {
        "ShareInvitationSummaries": List["ShareInvitationSummaryTypeDef"],
        "NextToken": str,
        "ResponseMetadata": "ResponseMetadata",
    },
    total=False,
)

ListTagsForResourceOutputTypeDef = TypedDict(
    "ListTagsForResourceOutputTypeDef",
    {"Tags": Dict[str, str], "ResponseMetadata": "ResponseMetadata"},
    total=False,
)

ListWorkloadSharesOutputTypeDef = TypedDict(
    "ListWorkloadSharesOutputTypeDef",
    {
        "WorkloadId": str,
        "WorkloadShareSummaries": List["WorkloadShareSummaryTypeDef"],
        "NextToken": str,
        "ResponseMetadata": "ResponseMetadata",
    },
    total=False,
)

ListWorkloadsOutputTypeDef = TypedDict(
    "ListWorkloadsOutputTypeDef",
    {
        "WorkloadSummaries": List["WorkloadSummaryTypeDef"],
        "NextToken": str,
        "ResponseMetadata": "ResponseMetadata",
    },
    total=False,
)

UpdateAnswerOutputTypeDef = TypedDict(
    "UpdateAnswerOutputTypeDef",
    {
        "WorkloadId": str,
        "LensAlias": str,
        "Answer": "AnswerTypeDef",
        "ResponseMetadata": "ResponseMetadata",
    },
    total=False,
)

UpdateLensReviewOutputTypeDef = TypedDict(
    "UpdateLensReviewOutputTypeDef",
    {"WorkloadId": str, "LensReview": "LensReviewTypeDef", "ResponseMetadata": "ResponseMetadata"},
    total=False,
)

UpdateShareInvitationOutputTypeDef = TypedDict(
    "UpdateShareInvitationOutputTypeDef",
    {"ShareInvitation": "ShareInvitationTypeDef", "ResponseMetadata": "ResponseMetadata"},
    total=False,
)

UpdateWorkloadOutputTypeDef = TypedDict(
    "UpdateWorkloadOutputTypeDef",
    {"Workload": "WorkloadTypeDef", "ResponseMetadata": "ResponseMetadata"},
    total=False,
)

UpdateWorkloadShareOutputTypeDef = TypedDict(
    "UpdateWorkloadShareOutputTypeDef",
    {
        "WorkloadId": str,
        "WorkloadShare": "WorkloadShareTypeDef",
        "ResponseMetadata": "ResponseMetadata",
    },
    total=False,
)
